#include <QtGui/QApplication>
#include "mainwindow.h"
#include "LocationModule.h"
#include <QTimer>
Speedo *pW;
int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    Speedo w;

    pW = &w;
    w.show();
    QTimer::singleShot(1000,&w,SLOT(start_gps() ));
    return a.exec();
}
